<?php
// $Id: openinviter_engine.admin.inc,v 1.1.2.2 2009/12/07 03:58:14 dalin Exp $

/**
 * @file
 *
 * Admin functions and forms for the OpenInviter import library.
 */

/**
 * The admin settings form.
 */
function openinviter_engine_admin() {
  $form = array();
  
  $form['openinviter_engine_transport'] = array(
    '#type' => 'select',
    '#title' => t('OpenInviter transport method'),
    '#default_value' => variable_get('openinviter_engine_transport', 'curl'),
    '#description' => t('The library to use for fetching URLs.'),
    '#required' => TRUE,
    '#options' => array(
      'curl' => t('curl'),
      'wget' => t('wget'),
    ),
  );

  $form['openinviter_engine_providers_email'] = array(
    '#type' => 'fieldset',
    '#title' => t('OpenInviter Email Providers'),
    '#descriptions' => t('Select the services users should be allowed to import contacts from.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#tree' => TRUE,
    '#theme' => 'openinviter_engine_admin_plugin_table',
  );
  $form['openinviter_engine_providers_social'] = array(
    '#type' => 'fieldset',
    '#title' => t('OpenInviter Social Network Providers '),
    '#descriptions' => t('Select the services users should be allowed to import contacts from.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#tree' => TRUE,
    '#theme' => 'openinviter_engine_admin_plugin_table',
  );

  $plugin_settings = array_merge(variable_get('openinviter_engine_providers_email', array()),
    variable_get('openinviter_engine_providers_social', array()));
  $import_plugins = openinviter_engine_get_providers();
  foreach ($import_plugins as $plugin => $details) {
    $default = !empty($plugin_settings) ? $plugin_settings[$plugin] : TRUE;
    $form['openinviter_engine_providers_' . $details['type']][$plugin] = array(
      '#type' => 'checkbox',
      '#title' => $details['name'],
      '#default_value' => $default,
    );
  }

  return system_settings_form($form);
}

/**
 * FAPI validation handler. Validate wether cURL/WGET are available.
 */
function openinviter_engine_admin_validate($form, &$form_state) {
  switch ($form_state['values']['openinviter_engine_transport']) {
   case 'curl':
     if (!function_exists('curl_init')) {
       drupal_set_message('The CURL PHP extension is not available.  Try using WGET instead.',
        'error');
     }
     break;
   case 'wget':
     $wget_info = passthru('wget --version');
     if (!strpos('GNU Wget', $wget_info)) {
       drupal_set_message('WGET is not available.  Try using CURL instead.', 'error');
     }
     break;
  }
}

/**
 * Theme function for the admin settings plugin table.
 * Displays the plugin checkboxes as a table
 */
function theme_openinviter_engine_admin_plugin_table(&$form) {
  $plugins = array();

  // Flatten forms array.
  foreach (element_children($form) as $plugin) {
    $plugins[] = drupal_render($form[$plugin]);
  }

  // Split checkboxes into rows with 3 columns.
  $total = count($plugins);
  $rows = array();
  for ($i = 0; $i < $total; $i++) {
    $row = array();
    $row[] = array('data' => $plugins[$i]);
    if (isset($plugins[++$i])) {
      $row[] = array('data' => $plugins[$i]);
    }
    if (isset($plugins[++$i])) {
      $row[] = array('data' => $plugins[$i]);
    }
    $rows[] = $row;
  }

  $output = theme('table', array(), $rows, array('width' => '100%'));

  return $output;
}
